@@ -1,4 +1,4 @@
-# $Id: TimedActionFixture.pm,v 1.7 2006/05/15 08:37:07 tonyb Exp $
+# $Id: TimedActionFixture.pm,v 1.8 2006/06/16 15:20:56 tonyb Exp $
 #
 # Copyright (c) 2002-2005 Cunningham & Cunningham, Inc.
 # Released under the terms of the GNU General Public License version 2 or later.
@@ -12,46 +12,43 @@ use base 'Test::C2FIT::ActionFixture';
 use strict;
 use Test::C2FIT::Parse;
 
-sub doTable
-{
-	my $self = shift;
-	my($table) = shift;
+sub doTable {
+    my $self = shift;
+    my ($table) = shift;
 
-	$self->SUPER::doTable($table);
-	$table->parts()->parts()->last()->more($self->td("time"));
-	$table->parts()->parts()->last()->more($self->td("split"));
+    $self->SUPER::doTable($table);
+    $table->parts()->parts()->last()->more( $self->td("time") );
+    $table->parts()->parts()->last()->more( $self->td("split") );
 }
 
 sub formatTime($) {
     my ($value) = @_;
     my @t = localtime($value);
-    my $r = sprintf("%2d:%02d:%02d",$t[2],$t[1],$t[0]);
-#    warn "SSS: $r\n";
+    my $r = sprintf( "%2d:%02d:%02d", $t[2], $t[1], $t[0] );
+
+    #    warn "SSS: $r\n";
     return $r;
 }
 
-sub doCells
-{
-	my $self = shift;
-	my($cells) = @_;
-	my $start = $self->time();
-	$self->SUPER::doCells($cells);
-	my $split = $self->time() - $start;
-	$cells->last()->more($self->td(formatTime($start)));
-	$cells->last()->more($self->td($split));		#TBD format?
+sub doCells {
+    my $self    = shift;
+    my ($cells) = @_;
+    my $start   = $self->time();
+    $self->SUPER::doCells($cells);
+    my $split = $self->time() - $start;
+    $cells->last()->more( $self->td( formatTime($start) ) );
+    $cells->last()->more( $self->td($split) );    #TBD format?
 }
 
-sub time
-{
-	my $self = shift;
-	return CORE::time();
+sub time {
+    my $self = shift;
+    return CORE::time();
 }
 
-sub td
-{
-	my $self = shift;
-	my($body) = @_;
-	return Test::C2FIT::Parse->from("td", $self->info($body), undef, undef);
+sub td {
+    my $self = shift;
+    my ($body) = @_;
+    return Test::C2FIT::Parse->from( "td", $self->info($body), undef, undef );
 }
 
 1;
